package com.abi.qms.platform.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.abi.qms.platform.dao.entity.BaseSapOrganization;
import com.abi.qms.platform.dao.mapper.BaseSapOrganizationMapper;
import com.abi.qms.platform.dto.req.BatchImportOrganizationReq;
import com.abi.qms.platform.infrastructure.util.AssertUtil;
import com.abi.qms.platform.service.BaseSapOrganizationService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author: fangxinjian
 * @date: 2021/06/01 17:20
 * @description:
 */
@Service
@Slf4j
public class BaseSapOrganizationServiceImpl implements BaseSapOrganizationService {

    @Autowired
    private BaseSapOrganizationMapper baseSapOrganizationMapper;


    @Override
    public void batchImportOrganization(BatchImportOrganizationReq req) {
        List<BatchImportOrganizationReq.SapOrganization> organizationList = req.getOrganizationList();

        for (BatchImportOrganizationReq.SapOrganization sap : organizationList) {

            try {
                BaseSapOrganization organization = new BaseSapOrganization();
                organization.setCustomerCode(sap.getCustomerCode());
                organization.setCustomerName(sap.getCustomerName());
                organization.setOrganizationLevel(sap.getOrganizationLevel());
                organization.setParentCode(sap.getParentCode());
                organization.setProvince(sap.getProvince());
                organization.setId(sap.getId());

                saveBaseSapOrganization(organization);
            } catch (Exception e) {
                log.error("导入组织架构数据失败", e);
            }
        }

    }

    public void saveBaseSapOrganization(BaseSapOrganization bso) {

        //校验入参 code不能重复
        QueryWrapper<BaseSapOrganization> qw = new QueryWrapper<>();
        qw.eq("customer_code", bso.getCustomerCode());
        if (bso.getId() != null) {
            qw.ne("id", bso.getId());
        }
        List<BaseSapOrganization> organizationList = baseSapOrganizationMapper.selectList(qw);
        if (CollectionUtil.isNotEmpty(organizationList)) {
            log.info("组织架构代码:{}已存在", bso.getCustomerCode());
        }

        if (bso.getId() != null) {
            BaseSapOrganization baseSapOrganization = baseSapOrganizationMapper.selectById(bso.getId());
            if (ObjectUtil.isNull(baseSapOrganization)) {
                log.info("组织架构代码:{}不存在", bso.getCustomerCode());
            }
        }

        //新增or修改
        if (bso.getId() != null) {
            baseSapOrganizationMapper.updateById(bso);
        } else {
            baseSapOrganizationMapper.insert(bso);
        }

    }
}
